@@ -53,8 +53,10 @@ class Credenciais(base.Plugavel):
         if not self._credenciador:
             try:
                 self._credenciador = self.plugin_seguranca.Credenciador(self.configuracao_pagamento)
-            except AttributeError:
-                raise AutenticadorNaoEncontrado(u"O meio de pagamento '{}' não possui a classe Credenciador.".format(self.meio_pagamento))
+            except AttributeError, ex:
+                if "Credenciador" in unicode(ex):
+                    raise AutenticadorNaoEncontrado(u"O meio de pagamento '{}' não possui a classe Credenciador.".format(self.meio_pagamento))
+                raise
         return self._credenciador
 
     def define_autenticacao(self, url=None, atualiza_autenticacao=False):
@@ -75,19 +77,10 @@ class Credenciais(base.Plugavel):
         return self.credenciador.esta_valido()
 
     def por_query_string(self):
-        try:
-            return "{}={}".format(self.credenciador.chave, self.credenciador.obter_credenciais())
-        except AttributeError:
-            raise CredenciadorInvalido(u"O credenciador {}.{} não implementa o método obter_credenciais(credenciamento=None).".format(self.credenciador.__module__, self.credenciador.__class__.__name__))
+        return "{}={}".format(self.credenciador.chave, self.credenciador.obter_credenciais())
 
     def por_form_urlencoded(self):
-        try:
-            return {self.credenciador.chave: self.credenciador.obter_credenciais()}
-        except AttributeError:
-            raise CredenciadorInvalido(u"O credenciador {}.{} não implementa o método obter_credenciais(credenciamento=None).".format(self.credenciador.__module__, self.credenciador.__class__.__name__))
+        return {self.credenciador.chave: self.credenciador.obter_credenciais()}
 
     def por_cabecalho_http(self, cabecalho="Authorization"):
-        try:
-            return {cabecalho: self.credenciador.obter_credenciais()}
-        except AttributeError:
-            raise CredenciadorInvalido(u"O credenciador {}.{} não implementa o método obter_credenciais(credenciamento=None).".format(self.credenciador.__module__, self.credenciador.__class__.__name__))
+        return {cabecalho: self.credenciador.obter_credenciais()}
